==> haskell-text-printer-0.5.0.1-78-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-printer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-printer
version:              0.5.0.1
visibility:           public
id:                   text-printer-0.5.0.1-3Ktbi6jdUZt23RTX9qh2fW
key:                  text-printer-0.5.0.1-3Ktbi6jdUZt23RTX9qh2fW
license:              BSD-3-Clause
copyright:            2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/text-printer
synopsis:             Abstract interface for text builders/printers.
description:
    This package provides an interface for injecting text into monoids such as
    builders and printers.

category:             Text
abi:                  68ed2ebc676d3c13117d840821628bd8
exposed:              True
exposed-modules:
    Text.Printer Text.Printer.Fractional Text.Printer.Integral

import-dirs:          /usr/lib/ghc-8.10.4/site-local/text-printer-0.5.0.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/text-printer-0.5.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/text-printer-0.5.0.1
hs-libraries:         HStext-printer-0.5.0.1-3Ktbi6jdUZt23RTX9qh2fW
depends:
    base-4.14.1.0 bytestring-0.10.12.0 pretty-1.1.3.6 text-1.2.4.1
    text-latin1-0.3.1-9a1cKjCgOF9A7XEhhwYQTz

haddock-interfaces:
    /usr/share/doc/haskell-text-printer/html/text-printer.haddock

haddock-html:         /usr/share/doc/haskell-text-printer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-printer-0.5.0.1-79-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-printer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-printer
version:              0.5.0.1
visibility:           public
id:                   text-printer-0.5.0.1-9z25XDlZA1G2orrdC8N5Bw
key:                  text-printer-0.5.0.1-9z25XDlZA1G2orrdC8N5Bw
license:              BSD-3-Clause
copyright:            2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/text-printer
synopsis:             Abstract interface for text builders/printers.
description:
    This package provides an interface for injecting text into monoids such as
    builders and printers.

category:             Text
abi:                  1a2b49e6845ef258bd19942718b61d63
exposed:              True
exposed-modules:
    Text.Printer Text.Printer.Fractional Text.Printer.Integral

import-dirs:          /usr/lib/ghc-8.10.4/site-local/text-printer-0.5.0.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/text-printer-0.5.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/text-printer-0.5.0.1
hs-libraries:         HStext-printer-0.5.0.1-9z25XDlZA1G2orrdC8N5Bw
depends:
    base-4.14.1.0 bytestring-0.10.12.0 pretty-1.1.3.6 text-1.2.4.1
    text-latin1-0.3.1-IgVpJkirrxA8AGCpbPlyHf

haddock-interfaces:
    /usr/share/doc/haskell-text-printer/html/text-printer.haddock

haddock-html:         /usr/share/doc/haskell-text-printer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
